@@ -7,7 +7,7 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-namespace Foo\DataProviderIssue2833;
+namespace PHPUnit\TestFixture\DataProviderIssue2833;
 
 use PHPUnit\Framework\TestCase;
 
