@@ -11,6 +11,7 @@
 namespace PHPUnit\Framework\MockObject;
 
 use function sprintf;
+use PHPUnit\Framework\Constraint\IsAnything;
 use PHPUnit\Framework\Constraint\IsEqual;
 use PHPUnit\Framework\MockObject\Builder\InvocationMocker;
 use PHPUnit\Framework\MockObject\Stub\ReturnSelf;
@@ -152,11 +153,11 @@ final class InvocationMockerTest extends TestCase
 
     public function testWillReturnAllowsMatchersForMultipleMethodsWithDifferentReturnTypes(): void
     {
-        /** @var ClassWithAllPossibleReturnTypes|\PHPUnit\Framework\MockObject\MockObject $mock */
+        /** @var ClassWithAllPossibleReturnTypes|MockObject $mock */
         $mock = $this->getMockBuilder(ClassWithAllPossibleReturnTypes::class)
             ->getMock();
 
-        $invocationMocker = $mock->method(new \PHPUnit\Framework\Constraint\IsAnything);
+        $invocationMocker = $mock->method(new IsAnything);
         $invocationMocker->willReturn(true, 1);
 
         $this->assertEquals(true, $mock->methodWithBoolReturnTypeDeclaration());
@@ -201,7 +202,7 @@ final class InvocationMockerTest extends TestCase
      */
     public function testWillReturnFailsWhenTryingToReturnValueFromVoidMethod(): void
     {
-        /** @var ClassWithAllPossibleReturnTypes|\PHPUnit\Framework\MockObject\MockObject $out */
+        /** @var ClassWithAllPossibleReturnTypes|MockObject $out */
         $out    = $this->createMock(ClassWithAllPossibleReturnTypes::class);
         $method = $out->method('methodWithVoidReturnTypeDeclaration');
 
