@@ -15,6 +15,7 @@ use function method_exists;
 use function microtime;
 use Countable;
 use Exception;
+use PHPUnit\Framework\InvalidArgumentException;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\TestFixture\AbstractTrait;
 use PHPUnit\TestFixture\AnInterface;
@@ -66,7 +67,7 @@ final class GeneratorTest extends TestCase
 
     public function testGetMockThrowsExceptionWithInvalidMethods(): void
     {
-        $this->expectException(\PHPUnit\Framework\InvalidArgumentException::class);
+        $this->expectException(InvalidArgumentException::class);
 
         $this->generator->getMock(stdClass::class, false);
     }
