@@ -86,7 +86,7 @@ class TestCaseTest extends TestCase
             $_SERVER['f'],
             $_FILES['g'],
             $_REQUEST['h'],
-            $GLOBALS['i']
+            $GLOBALS['i'],
         );
     }
 
