@@ -16,6 +16,7 @@ use function realpath;
 use PharIo\Version\VersionConstraint;
 use PHPUnit\Framework\CodeCoverageException;
 use PHPUnit\Framework\ExecutionOrderDependency;
+use PHPUnit\Framework\ExpectationFailedException;
 use PHPUnit\Framework\InvalidDataProviderException;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\Framework\Warning;
@@ -66,6 +67,7 @@ use PHPUnit\TestFixture\VariousIterableDataProviderTest;
 use PHPUnit\Util\Annotation\DocBlock;
 use ReflectionClass;
 use ReflectionMethod;
+use SebastianBergmann\RecursionContext\InvalidArgumentException;
 
 /**
  * @small
@@ -82,8 +84,8 @@ final class TestClassTest extends TestCase
      *
      * @dataProvider requirementsProvider
      *
-     * @throws \PHPUnit\Framework\ExpectationFailedException
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
+     * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      * @throws Warning
      */
     public function testGetRequirements($test, $result): void
@@ -529,9 +531,9 @@ final class TestClassTest extends TestCase
      *
      * @dataProvider requirementsWithVersionConstraintsProvider
      *
-     * @throws \PHPUnit\Framework\ExpectationFailedException
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws Exception
+     * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      * @throws Warning
      */
     public function testGetRequirementsWithVersionConstraints($test, array $result): void
@@ -722,8 +724,8 @@ final class TestClassTest extends TestCase
      *
      * @dataProvider missingRequirementsProvider
      *
-     * @throws \PHPUnit\Framework\ExpectationFailedException
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
+     * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      * @throws Warning
      */
     public function testGetMissingRequirements($test, $result): void
@@ -1226,9 +1228,9 @@ final class TestClassTest extends TestCase
     /**
      * @dataProvider getLinesToBeCoveredProvider
      *
-     * @throws \PHPUnit\Framework\ExpectationFailedException
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws CodeCoverageException
+     * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testGetLinesToBeCovered($test, $expected): void
     {
